For full description and instructions please refer to the `Github repository`_ and the corresponding `CAMSA wiki`_.

.. _Github repository: https://github.com/aganezov/camsa
.. _CAMSA wiki: https://github.com/aganezov/camsa/wiki